@@ -63,12 +63,17 @@ class TimeSheet(models.Model):
         return 20
 
     def prepare(self):
-        for tsc in mdm.TimeSheetCategory.objects.all():
-            TimeSheetStatistic.objects.create(category=tsc, sheet=self)
+        for presence_type in mdm.TimeSheetCategory.objects.all():
+            TimeSheetStatistic.objects.create(category=presence_type, sheet=self)
+        for absence_type in mdm.PauseCategory.objects.all():
+            AbsenseStatistic.objects.create(category=absence_type, sheet=self)
 
     def summarize(self):
-        for stat in TimeSheetStatistic.objects.filter(sheet=self):
-            stat.close()
+        [presence_stat.close() for presence_stat in TimeSheetStatistic.objects.filter(sheet=self)]
+        [absence_stat.close() for absence_stat in AbsenseStatistic.objects.filter(sheet=self)]
+
+    def __str__(self):
+        return '{year}/{month}'.format(year=self.current_year, month=calendar.month_name[self.current_month])
 
 class TimeSheetItem(models.Model):
     sheet = models.ForeignKey(
@@ -77,12 +82,25 @@ class TimeSheetItem(models.Model):
         related_name='items',
         on_delete=models.CASCADE,
     )
-    category = models.ForeignKey(
+    presence = models.ForeignKey(
         verbose_name=_("típus"),
         to=mdm.TimeSheetCategory,
-        related_name='aspects',
+        related_name='sheets',
         on_delete=models.CASCADE,
+        null=True,
+        blank=True,
+        default=None
     )
+    absence = models.ForeignKey(
+        verbose_name=_("típus"),
+        to=mdm.PauseCategory,
+        related_name='sheets',
+        on_delete=models.CASCADE,
+        null=True,
+        blank=True,
+        default=None
+    )
+
     timestamp = models.DateField(
         verbose_name=_("dátum")
     )
@@ -94,13 +112,13 @@ class TimeSheetStatistic(models.Model):
     sheet = models.ForeignKey(
         verbose_name=_("jelenléti"),
         to=TimeSheet,
-        related_name='statistics',
+        related_name='presences',
         on_delete=models.CASCADE,
     )
     category = models.ForeignKey(
         verbose_name=_("kategória"),
         to=mdm.TimeSheetCategory,
-        related_name='categories',
+        related_name='presences',
         on_delete=models.CASCADE,
     )
     value = models.DurationField(
@@ -113,7 +131,37 @@ class TimeSheetStatistic(models.Model):
     def calculate(self) -> timezone.timedelta:
         return TimeSheetItem.objects.filter(
             sheet=self.sheet,
-            category=self.category
+            presence=self.category
+        ).aggregate(Sum('duration'))
+
+    def close(self):
+        self.value = self.calculate
+
+
+class AbsenseStatistic(models.Model):
+    sheet = models.ForeignKey(
+        verbose_name=_("jelenléti"),
+        to=TimeSheet,
+        related_name='absenses',
+        on_delete=models.CASCADE,
+    )
+    category = models.ForeignKey(
+        verbose_name=_("kategória"),
+        to=mdm.PauseCategory,
+        related_name='absences',
+        on_delete=models.CASCADE,
+    )
+    value = models.DurationField(
+        blank=True,
+        null=True,
+        default=None
+    )
+
+    @property
+    def calculate(self) -> timezone.timedelta:
+        return TimeSheetItem.objects.filter(
+            sheet=self.sheet,
+            absence=self.category
         ).aggregate(Sum('duration'))
 
     def close(self):
@@ -315,10 +363,13 @@ class Payroll(MonthBasedMixin, Process):
         on_delete=models.CASCADE
     )
 
-    employer = models.ForeignKey(
-        verbose_name=_('foglalkoztató'),
-        to=Customer,
-        on_delete=models.CASCADE
+    timesheet = models.ForeignKey(
+        verbose_name=_('alkalmazott'),
+        to=TimeSheet,
+        on_delete=models.CASCADE,
+        blank=True,
+        null=True,
+        default=None,
     )
 
     submitted = models.NullBooleanField(
